@@ -1,12 +1,16 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
 #ifndef WJAVASCRIPTSLOT_H_
 #define WJAVASCRIPTSLOT_H_
 
+#if defined(WT_THREADED) || defined(WT_TARGET_JAVA)
+#include <atomic>
+#endif
+
 #include "Wt/WObject.h"
 
 namespace Wt {
@@ -205,8 +209,13 @@ private:
   WStatelessSlot* slotimp();
   void create();
 
-  int fid_;
-  static int nextFid_;
+  const unsigned fid_;
+
+#if defined(WT_THREADED) || defined(WT_TARGET_JAVA)
+  static std::atomic<unsigned> nextFid_;
+#else
+  static unsigned nextFid_;
+#endif
 
   int nbArgs_;
 
