@@ -30,7 +30,7 @@ private:
 };
 
 SAMPLE_BEGIN(PaintingEvent)
-auto container = Wt::cpp14::make_unique<Wt::WContainerWidget>();
+auto container = std::make_unique<Wt::WContainerWidget>();
 
 MyPaintedWidget *painting = container->addNew<MyPaintedWidget>();
 
